@@ -113,7 +113,7 @@ new LambdaToSqsToLambda(this, "LambdaToSqsToLambdaPattern", new LambdaToSqsToLam
 |maxReceiveCount?|`number`|The number of times a message can be unsuccessfully dequeued before being moved to the dead letter queue. Defaults to `15`.|
 |existingConsumerLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|An optional, existing Lambda function to be used instead of the default function for receiving/consuming messages from the queue. Providing both this and `consumerLambdaFunctionProps` will cause an error. |
 |consumerLambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|Optional user-provided properties to override the default properties for the consumer Lambda function.|
-|queueEnvironmentVariableName?|`string`|Optional Name for the SQS queue URL environment variable set for the producer Lambda function.|
+|queueEnvironmentVariableName?|`string`|Optional Name for the Lambda function environment variable set to the URL of the queue. Default: SQS_QUEUE_URL |
 |sqsEventSourceProps?| [`SqsEventSourceProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda-event-sources.SqsEventSourceProps.html)|Optional user provided properties for the queue event source.|
 |existingVpc?|[`ec2.IVpc`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.IVpc.html)|An optional, existing VPC into which this pattern should be deployed. When deployed in a VPC, the Lambda function will use ENIs in the VPC to access network resources and an Interface Endpoint will be created in the VPC for Amazon SQS. If an existing VPC is provided, the `deployVpc` property cannot be `true`. This uses `ec2.IVpc` to allow clients to supply VPCs that exist outside the stack using the [`ec2.Vpc.fromLookup()`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.Vpc.html#static-fromwbrlookupscope-id-options) method.|
 |vpcProps?|[`ec2.VpcProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.VpcProps.html)|Optional user-provided properties to override the default properties for the new VPC. `enableDnsHostnames`, `enableDnsSupport`, `natGateways` and `subnetConfiguration` are set by the pattern, so any values for those properties supplied here will be overrriden. If `deployVpc` is not `true` then this property will be ignored.|
@@ -155,7 +155,7 @@ Out-of-the-box implementation of this Construct (without any overridden properti
 ---
 
 
-© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -218,7 +218,7 @@ class LambdaToSqsToLambda(
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         :param max_receive_count: The number of times a message can be unsuccessfully dequeued before being moved to the dead letter queue. Defaults to ``15``. Default: - 15.
         :param producer_lambda_function_props: Optional user-provided properties to override the default properties for the producer Lambda function. Default: - Default properties are used.
-        :param queue_environment_variable_name: Optional Name for the SQS queue URL environment variable set for the producer Lambda function. Default: - None
+        :param queue_environment_variable_name: Optional Name for the Lambda function environment variable set to the URL of the queue. Default: - SQS_QUEUE_URL
         :param queue_props: Optional user-provided properties to override the default properties for the SQS queue. Default: - Default props are used.
         :param sqs_event_source_props: Optional user provided properties for the queue event source. Default: - Default props are used
         :param vpc_props: Properties to override default properties if deployVpc is true.
@@ -321,7 +321,7 @@ class LambdaToSqsToLambdaProps:
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         :param max_receive_count: The number of times a message can be unsuccessfully dequeued before being moved to the dead letter queue. Defaults to ``15``. Default: - 15.
         :param producer_lambda_function_props: Optional user-provided properties to override the default properties for the producer Lambda function. Default: - Default properties are used.
-        :param queue_environment_variable_name: Optional Name for the SQS queue URL environment variable set for the producer Lambda function. Default: - None
+        :param queue_environment_variable_name: Optional Name for the Lambda function environment variable set to the URL of the queue. Default: - SQS_QUEUE_URL
         :param queue_props: Optional user-provided properties to override the default properties for the SQS queue. Default: - Default props are used.
         :param sqs_event_source_props: Optional user provided properties for the queue event source. Default: - Default props are used
         :param vpc_props: Properties to override default properties if deployVpc is true.
@@ -484,9 +484,9 @@ class LambdaToSqsToLambdaProps:
 
     @builtins.property
     def queue_environment_variable_name(self) -> typing.Optional[builtins.str]:
-        '''Optional Name for the SQS queue URL environment variable set for the producer Lambda function.
+        '''Optional Name for the Lambda function environment variable set to the URL of the queue.
 
-        :default: - None
+        :default: - SQS_QUEUE_URL
         '''
         result = self._values.get("queue_environment_variable_name")
         return typing.cast(typing.Optional[builtins.str], result)
